EglInitializeResult class

Constructors

EglInitializeResult({required int majorVersion, required int minorVersion})

Properties

hashCode → int
The hash code for this object.
no setterinherited
majorVersion → int
final
minorVersion → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited