LPCURRENCYFMTW class final

Inheritance
Implemented types
Available extensions

Constructors

LPCURRENCYFMTW()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
Grouping ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
LeadingZero ↔ int
getter/setter pair
lpCurrencySymbol ↔ Pointer<Uint16>
getter/setter pair
lpDecimalSep ↔ Pointer<Uint16>
getter/setter pair
lpThousandSep ↔ Pointer<Uint16>
getter/setter pair
NegativeOrder ↔ int
getter/setter pair
NumDigits ↔ int
getter/setter pair
PositiveOrder ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited