PACTCTXA class final

Inheritance
Implemented types
Available extensions

Constructors

PACTCTXA()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cbSize ↔ int
getter/setter pair
dwFlags ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hModule ↔ Pointer<HINSTANCE__>
getter/setter pair
lpApplicationName ↔ Pointer<Int8>
getter/setter pair
lpAssemblyDirectory ↔ Pointer<Int8>
getter/setter pair
lpResourceName ↔ Pointer<Int8>
getter/setter pair
lpSource ↔ Pointer<Int8>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wLangId ↔ int
getter/setter pair
wProcessorArchitecture ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited