RenderingContext class

Constructors

RenderingContext.create(LibOpenGLES gl, int width, int height, [bool checkGlErrorOnEveryCall = false])

Properties

checkGlErrorOnEveryCall → bool
final
drawingBufferColorSpace ← String
no getter
gl → LibOpenGLES
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unpackColorSpace ← String
no getter
width → int
final

Methods

activeTexture(int texture) → void
attachShader(Program program, WebGLShader shader) → void
beginTransformFeedback(int primitiveMode) → void
bindAttribLocation(Program program, int index, String name) → void
bindBuffer(int target, Buffer? buffer) → void
bindBufferBase(int target, int index, Buffer? buffer) → void
bindFramebuffer(int target, Framebuffer? framebuffer) → void
bindRenderbuffer(int target, Renderbuffer? renderbuffer) → void
bindTexture(int target, WebGLTexture? texture) → void
bindTransformFeedback(int target, TransformFeedback feedback) → void
bindVertexArray(VertexArrayObject array) → void
blendEquation(int mode) → void
blendEquationSeparate(int modeRGB, int modeAlpha) → void
blendFunc(int sfactor, int dfactor) → void
blendFuncSeparate(int srcRGB, int dstRGB, int srcAlpha, int dstAlpha) → void
blitFramebuffer(int srcX0, int srcY0, int srcX1, int srcY1, int dstX0, int dstY0, int dstX1, int dstY1, int mask, int filter) → void
bufferData(int target, dynamic data, int? usage) → void
Be careful which type of integer you really pass here. Unfortunately an UInt16List is viewed by the Dart type system just as List
bufferDataTyped(int target, TypedData data, int? usage) → void
Be careful which type of integer you really pass here. Unfortunately an UInt16List is viewed by the Dart type system just as List
bufferDataVoid(int target, int data, int? usage) → void
Be careful which type of integer you really pass here. Unfortunately an UInt16List is viewed by the Dart type system just as List
bufferSubData(int target, int dstByteOffset, TypedData srcData) → void
checkError([String message = '']) → void
As allocating and freeing native memory is expensive and we need regularly buffers to receive values from FFI function we create a small set here that will be reused constantly
checkFramebufferStatus(int target) → int
clear(int mask) → void
clearBufferiv(int buffer, int drawbuffer, int value) → void
clearBufferuiv(int buffer, int drawbuffer, int value) → void
clearColor(double red, double green, double blue, double alpha) → void
clearDepth(double depth) → void
clearStencil(int s) → void
colorMask(bool red, bool green, bool blue, bool alpha) → void
compileShader(WebGLShader shader, [bool checkForErrors = true]) → void
compressedTexImage2D(int target, int level, int internalformat, int width, int height, int border, TypedData? pixels) → void
compressedTexImage3D(int target, int level, int internalformat, int width, int height, int depth, int border, TypedData? pixels) → void
compressedTexSubImage2D(int target, int level, int xoffset, int yoffset, int width, int height, int format, TypedData? pixels) → void
compressedTexSubImage3D(int target, int level, int xoffset, int yoffset, int zoffset, int width, int height, int depth, int format, TypedData? pixels) → void
copyTexImage2D(int target, int level, int internalformat, int x, int y, int width, int height, int border) → void
copyTexSubImage2D(int target, int level, int xoffset, int yoffset, int x, int y, int width, int height) → void
copyTexSubImage3D(int target, int level, int xoffset, int yoffset, int zoffset, int x, int y, int width, int height) → void
createBuffer() → Buffer
createFramebuffer() → Framebuffer
createProgram() → Program
createRenderbuffer() → Renderbuffer
createShader(int type) → WebGLShader
createTexture() → WebGLTexture
createTransformFeedback() → TransformFeedback
createVertexArray() → VertexArrayObject
cullFace(int mode) → void
deleteBuffer(Buffer buffer) → void
deleteFramebuffer(Framebuffer? framebuffer) → void
deleteProgram(Program program) → void
deleteRenderbuffer(Renderbuffer renderbuffer) → void
deleteShader(WebGLShader shader) → void
deleteTexture(WebGLTexture texture) → void
deleteTransformFeedback(TransformFeedback feedback) → void
deleteVertexArray(VertexArrayObject array) → void
depthFunc(int func) → void
depthMask(bool flag) → void
disable(int cap) → void
disableVertexAttribArray(int index) → void
drawArrays(int mode, int first, int count) → void
drawArraysInstanced(int mode, int first, int count, int instanceCount) → void
drawBuffers(Uint32List buffers) → void
drawElements(int mode, int count, int type, int offset) → void
drawElementsInstanced(int mode, int count, int type, int offset, int instanceCount) → void
enable(int cap) → void
enableVertexAttribArray(int index) → void
endTransformFeedback() → void
finish() → void
flush() → void
framebufferRenderbuffer(int target, int attachment, int renderbuffertarget, Renderbuffer? renderbuffer) → void
framebufferTexture2D(int target, int attachment, int textarget, WebGLTexture? texture, int level) → void
framebufferTextureLayer(int target, int attachment, WebGLTexture? texture, int level, int layer) → void
frontFace(int mode) → void
generateMipmap(int target) → void
getActiveAttrib(Program v0, int v1) → ActiveInfo
getActiveUniform(Program v0, int v1) → ActiveInfo
getAttribLocation(Program program, String name) → UniformLocation
getContextAttributes() → dynamic
getError() → int
getExtension(String key) → Object?
getExtensionMacos(String key) → List<String>
getIntegerv(int v0) → int
getParameter(int key) → int
getProgramInfoLog(Program program) → String?
getProgramParameter(Program program, int pname) → WebGLParameter
getShaderInfoLog(WebGLShader shader) → String?
getShaderParameter(WebGLShader shader, int pname) → bool
getShaderPrecisionFormat(int shadertype, int precisiontype) → ShaderPrecisionFormat
getShaderSource(int shader) → String?
getStringi(int key, int index) → String
getTransformFeedbackVarying(Program program, int index) → ActiveInfo
getUniformBlockIndex(Program program, String uniformBlockName) → int
getUniformLocation(Program program, String name) → UniformLocation
invalidateFramebuffer(int target, Uint32List attachments) → void
isProgram(Program program) → bool
isTransformFeedback(TransformFeedback feedback) → bool
lineWidth(double width) → void
linkProgram(Program program, [bool checkForErrors = true]) → void
loadImageFromAsset(String assetPath) → Future<Image>
makeXRCompatible() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseTransformFeedback() → void
pixelStorei(int pname, int param) → void
polygonOffset(double factor, double units) → void
readPixels(int x, int y, int width, int height, int format, int type, TypedData? pixels) → void
renderbufferStorage(int target, int internalformat, int width, int height) → void
renderbufferStorageMultisample(int target, int samples, int internalformat, int width, int height) → void
resumeTransformFeedback() → void
scissor(int x, int y, int width, int height) → void
shaderSource(WebGLShader shader, String shaderSource) → void
startCheck(String type) → void
stencilFunc(int func, int ref, int mask) → void
stencilMask(int mask) → void
stencilOp(int fail, int zfail, int zpass) → void
texImage2D(int target, int level, int internalformat, int width, int height, int border, int format, int type, TypedData? pixels) → void
texImage2D_NOSIZE(int target, int level, int internalformat, int format, int type, TypedData? pixels) → void
texImage2DfromAsset(int target, String assetPath, {int level = 0, int internalformat = WebGL.RGBA32UI, int format = WebGL.RGBA, int type = WebGL.UNSIGNED_INT}) → Future<void>
texImage2DfromImage(int target, Image image, {int level = 0, int internalformat = WebGL.RGBA, int format = WebGL.RGBA, int type = WebGL.UNSIGNED_BYTE}) → Future<void>
texImage3D(int target, int level, int internalformat, int width, int height, int depth, int border, int format, int type, TypedData? pixels) → void
texParameterf(int target, int pname, double param) → void
texParameteri(int target, int pname, int param) → void
texStorage2D(int target, int levels, int internalformat, int width, int height) → void
texStorage3D(int target, int levels, int internalformat, int width, int height, int depth) → void
texSubImage2D(int target, int level, int xoffset, int yoffset, int width, int height, int format, int type, TypedData? pixels) → void
texSubImage2D_NOSIZE(int target, int level, int xoffset, int yoffset, int format, int type, TypedData? pixels) → void
texSubImage3D(int target, int level, int xoffset, int yoffset, int zoffset, int width, int height, int depth, int format, int type, TypedData? pixels) → void
toString() → String
A string representation of this object.
inherited
transformFeedbackVaryings(Program program, int count, List<String> varyings, int bufferMode) → void
uniform1f(UniformLocation location, double x) → void
uniform1fv(UniformLocation location, Float32List v) → void
uniform1i(UniformLocation location, int x) → void
uniform1iv(UniformLocation location, Int32List v) → void
uniform1ui(UniformLocation? location, int v0) → void
uniform1uiv(UniformLocation? location, Uint32List v) → void
uniform2f(UniformLocation location, double x, double y) → void
uniform2fv(UniformLocation location, Float32List v) → void
uniform2i(UniformLocation location, int x, int y) → void
uniform2iv(UniformLocation location, Int32List v) → void
uniform2ui(UniformLocation? location, int v0, int v1) → void
uniform2uiv(UniformLocation? location, Uint32List v) → void
uniform3f(UniformLocation location, double x, double y, double z) → void
uniform3fv(UniformLocation location, Float32List vectors) → void
uniform3iv(UniformLocation location, Int32List v) → void
uniform3ui(UniformLocation? location, int v0, int v1, int v2) → void
uniform3uiv(UniformLocation? location, Uint32List v) → void
uniform4f(UniformLocation location, double x, double y, double z, double w) → void
uniform4fv(UniformLocation location, Float32List vectors) → void
uniform4iv(UniformLocation location, Int32List v) → void
uniform4ui(UniformLocation? location, int v0, int v1, int v2, int v3) → void
uniform4uiv(UniformLocation? location, Uint32List v) → void
uniformBlockBinding(Program program, int uniformBlockIndex, int uniformBlockBinding) → void
uniformMatrix2fv(UniformLocation location, bool transpose, Float32List values) → void
uniformMatrix3fv(UniformLocation location, bool transpose, Float32List values) → void
uniformMatrix4fv(UniformLocation location, bool transpose, Float32List values) → void
be careful, data always has a length that is a multiple of 16
useProgram(Program? program) → void
vertexAttrib1fv(int index, Float32List values) → void
vertexAttrib2fv(int index, Float32List values) → void
vertexAttrib3fv(int index, Float32List values) → void
vertexAttrib4fv(int index, Float32List values) → void
vertexAttribDivisor(int index, int divisor) → void
vertexAttribIPointer(int index, int size, int type, int stride, int pointer) → void
vertexAttribPointer(int index, int size, int type, bool normalized, int stride, int offset) → void
viewport(int x, int y, int width, int height) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited