ZeroCopyBuffer class

Constructors

ZeroCopyBuffer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFloat32(int length) Float32List
Allocates an un-shiftable, persistent C-heap memory block and exposes it as a standard, high-speed Dart Float32List view. Zero allocations per frame!
createUint32(int length) Uint32List
free(TypedData view) → void