RenderWorker class

Constructors

RenderWorker(FlutterAngleTexture texture)

Properties

fragmentShader → String
final
fxaaFragmentShader → String
final
fxaaVertexShader → String
final
hashCode → int
The hash code for this object.
no setterinherited
oesFragmentShader → String
final
oesVertexShader → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertexBuffer ↔ Buffer
latefinal
vertexBuffer4FBO ↔ Buffer
latefinal
vertexShader → String
final
vertexShaderAndroid → String
final

Methods

dispose() → void
drawTexture({required WebGLTexture? texture, required Buffer vertexBuffer, Float32List? matrix}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderTexture(WebGLTexture? texture, {Float32List? matrix, bool isFBO = false}) → void
setupVBO() → void
setupVBO4FBO() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited