RenderWorker class

Constructors

RenderWorker(FlutterAngleTexture texture)

Properties

fragment_shader → String
final
fxaa_fragment_shader → String
final
fxaa_vertex_shader → String
final
hashCode → int
The hash code for this object.
no setterinherited
oes_fragment_shader → String
final
oes_vertex_shader → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertex_shader → String
final
vertex_shader_android → String
final
vertexBuffer ↔ Buffer
latefinal
vertexBuffer4FBO ↔ Buffer
latefinal

Methods

dispose() → void
drawTexture({required WebGLTexture? texture, required Buffer vertexBuffer, Float32List? matrix}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderTexture(WebGLTexture? texture, {Float32List? matrix, bool isFBO = false}) → void
setupVBO() → void
setupVBO4FBO() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited